@@ -1,6 +1,6 @@
 ;;; tree-sitter-hl.el --- Syntax highlighting based on tree-sitter -*- lexical-binding: t; coding: utf-8 -*-
 
-;; Copyright (C) 2020-2025 emacs-tree-sitter maintainers
+;; Copyright (C) 2020-2026 emacs-tree-sitter maintainers
 ;;
 ;; Author: Tuấn-Anh Nguyễn <ubolonton@gmail.com>
 ;;         Timo von Hartz <c0untlizzi@gmail.com>
@@ -167,6 +167,11 @@
   "Face for special strings, e.g. regular expressions."
   :group 'tree-sitter-hl-faces)
 
+(defface tree-sitter-hl-face:string.special.path
+  '((default :inherit tree-sitter-hl-face:string.special))
+  "Face for special strings, e.g. path."
+  :group 'tree-sitter-hl-faces)
+
 (defface tree-sitter-hl-face:character
   '((default :inherit font-lock-string-face))
   "Face for characters."
@@ -306,6 +311,16 @@
 It's up to themes how they should be displayed: dimmed, hidden..."
   :group 'tree-sitter-hl-faces)
 
+(defface tree-sitter-hl-face:diff.plus
+  '((default :inherit diff-added))
+  "Face used to highlight addition."
+  :group 'tree-sitter-hl-faces)
+
+(defface tree-sitter-hl-face:diff.minus
+  '((default :inherit diff-removed))
+  "Face used to highlight deletion."
+  :group 'tree-sitter-hl-faces)
+
 ;;; ----------------------------------------------------------------------------
 ;;; Interfaces for modes and end users.
 
